function gmmCcapm_d()
 
// PURPOSE: Estimation of a power utility CCAPM model
// Example written by Mike Cliff, Purdue Finance,  mcliff@mgmt.purdue.edu
 
 
global GROCERDIR;
 
lines(0);
 
disp('---------------------------------------------------------------------')
disp('GMM Demo:  Application is (nonlinear) Asset Pricing Test')
disp(' The economic structure is E[Rm] = 1')
disp('  R is a NxT matrix of returns, N assets, T dates')
disp('  m is the Intertemporal Marginal Rate of Substitution (IMRS)')
disp('  it is a discount rate that makes the price of the asset 1')
disp('  It is T-dimensional vector.')
disp(' ')
disp('The model for m is m = b(1)*cg^(-b(2))')
disp('  b(1) is an impatience parameter')
disp('  b(2) is the risk aversion parameter (>0)')
disp('  cg is the consumption growth rate c_t/c_(t-1)')
disp(' The returns are real value-weighted market return and T-bill')
disp(' For instruments we will use lagged values of R and cg and a constant')
disp('---------------------------------------------------------------------')
disp(' ')
disp(' ')
disp(' ')
disp('Hit a key to continue')
halt()
 
lines(0);
gmmdata=read(GROCERDIR+'/data/gmmdata.txt',-1,3);// Sample data from Ogaki
rawdata = gmmdata(1:330,:);         // The last few obs are weird
nz = 1;                             // Number of lags used as instruments
T = size(rawdata,1)-nz;
neq = size(rawdata,2)-1;
 
cg = rawdata(1+nz:T+nz,1);
R = rawdata(1+nz:T+nz,2:3);
 
y = ones(T,neq);
X = [cg R];
Z = ones(T,1);
for i = 1:nz
  Z = [Z rawdata(1+nz-i:T+nz-i,1:3)];
end
 
disp(' ')
disp(' ')
disp(' We give GMM instructions through the gmmopt tlist:')
disp(' We refernce the moment conditions and derivatives')
disp(' and specify a Newey-West weighting matrix with 12 lags')
disp(' Starting values are b(1)=.98 and b(2) = 4')
 
gmmopt = tlist(['gmm';'momt';'jake';'prt';'gmmit';'W0';'W';'S';'lags';'namep';'null']);
gmmopt('momt')='gmmCcapmM';			// moment conditions
gmmopt('jake')='gmmCcapmJ';			// Deriv of moment cond.
gmmopt('gmmit') = 2;			// Number of GMM iterations
gmmopt('W0') = 'Z';			// Initial weighting matrix
gmmopt('W')='S';				// Subsequent wtg matrix optimal
gmmopt('S')='NW';				// Select subsequent wtg matrix
gmmopt('lags')=12;				// Lags in weighting matrix
gmmopt('prt')=1;			// Control printing
gmmopt('namep') = ['beta','gamma'];	// variable names
b=[.98;5];				// Starting values
gmmopt('null') = [1;0];			// Null hypothesis
 
disp('Hit a key to begin the estimation')
halt()
 
gout=gmm('y',gmmopt,'exo=''X''','ivar=''Z''','parm0=b');
 
return
 
endfunction
 
