function []=fan_chart(mat,dat,win,colour,sep,leg,sizes)
 
// PURPOSE: draws a fan-chart as the ones used by the Bank of
// England
// ------------------------------------------------------------
// INPUT:
// * mat=a (T x k) probability matrix
// * dat=a (T x 1) vector of dates
// * win=the window's number
// * colour='blue' or 'grey'
// * sep=the decimal separator used for the figures
// * leg = a boolean indicating whether a legend is added to
//   the chart
// * sizes = the confidence interval sizes displayed in the
//   legend (if any)
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the graphic window
// ------------------------------------------------------------
// Copyright: Eric Dubois 2008
// http://dubois.ensae.net/grocer.html

global GROCERDIR ;
 
[nargout,nargin]=argn(0)
if nargin <= 5 then
   leg=%f
end
if nargin <= 4 then
   sep='.'
end

band_width=mat($,:)-mat(1,:)
ind_fore=find(band_width~=0)
ind_lastdata=ind_fore(1)-1
// load the parameters that determines the fonts
load(GROCERDIR+'/param/param_g.dat')
just_scale=%f

if ~isempty(win) then
   scf(win)
   clf(win)
end
f=gcf()
cmap0=f.color_map
ncolors0=size(cmap0,1)

drawlater()
nbands=size(mat,1)
nx=size(mat,2)
a=gca()
a.data_bounds=[1,min(mat);nx,max(mat)]
half=floor(nbands/2)+1
 
select colour
 
case 'blue' then
   if half >=5 then
      cmap=[cmap0; 0 0 0 ; [0.2 0.3 0.4 linspace(0.5,0.8,half-4)]' .*. ones(1,2) 0.9*ones(half-1,1)]
   else
      cmap=[cmap0; 0 0 0 ; [linspace(0.2,0.8,half-1)]' .*. ones(1,2) 0.9*ones(half-1,1)]
   end  
   f.color_map=cmap
   colors=ncolors0+1:ncolors0+half
 
case 'grey'
   f.color_map=[cmap0 graycolormap(4*nbands)]
   colors=[ncolors0+1 ncolors0+3*nbands-floor(5*[half:-1:1]-16)]

else
    if or(colour == ['autumn' ; 'bone' ; 'cool' ; 'copper' ; 'hot' ;'ocean' ;'pink' ;'spring' ; 'summer';'winter'])  then
       cmap=[cmap0 ; evstr(colour+'colormap('+string(4*nbands))]
       colors()
    else
       error(colour+' is not available for a fan chart')
       colors=[ncolors0+1 ncolors0+4*nbands-floor(5*[half:-1:1]-16)]
    end
end
 
[y0,scale]=drawy(mat',font_axis,[],1,'l',just_scale,0,sep,%t)
nscale=size(scale,2)
drawx(dat,1,ref_nbinter,font_axis,y0)

// if the user wants alegend, then start with it, so that the
// curve is not covered by the legend
if leg then
   // select if it should be below or above the known data
   length_axex=size(mat,2)
   rect=xstringl(1+0.1*length_axex,0,'50% confidence interval')
   ind_mat=ceil(rect(1)+rect(3))
   scalemin=scale(1)
   scalemax=scale($)
   dist=[min(mat(1,1:ind_mat)-scalemin)  scalemax-max(mat(1,1:ind_mat))]

   [junk,ind_maxdist]=max(dist)
   if ind_maxdist == 1 then
      upper=0.7*scalemin+0.3*scalemax
   else
      upper=0.95*scalemax+0.05*scalemin
   end
   width=(scalemax-scalemin)*0.45
   xpoly(1+[0.02 0.08]*length_axex,(upper-0.1*width)*[1 1])
   e=gce()
   e.line_style=1
   e.thickness=5
   
   xstring(1+0.1*length_axex,(upper-0.14*width)*[1 1],' ')
   f=gce()
   f.font_size=4
   f.text='Median forecast'

   for i=1:half-1  
      xset('color',colors(half-i+1))
      xfpoly([1+[0.02 0.08]*length_axex 1+0.08*length_axex 1+0.02*length_axex],...
             [(upper-(0.14+0.12*i)*width)*[1 1] (upper-(0.10+0.12*(i+1))*width)*[1 1]])
      xstring(1+0.1*length_axex,upper-(0.22+0.12*i)*width,' ')
      f=gce()
      f.font_size=4
      f.text=string(100*sizes(half-i))+'% confidence interval' 
   end
      
end

xset("line style",1)
for i=1:half-2
   xset('color',colors(half-i+1))
   xfpoly([ind_lastdata:nx nx:-1:ind_lastdata],[mat(i,ind_lastdata:nx) mat(i+1,nx:-1:ind_lastdata)])
   xfpoly([ind_lastdata:nx nx:-1:ind_lastdata],[mat(nbands-i+1,ind_lastdata:nx) mat(nbands-i,nx:-1:ind_lastdata)])
end
 
rectc=[1 scale(1) nx scale($)]
// band at the center
xset('color',colors(2))
xfpoly([ind_lastdata:nx nx:-1:ind_lastdata],[mat(half-1,ind_lastdata:nx) mat(half+1,nx:-1:ind_lastdata)])
 
xset('color',1)
plot2d([1:nx],mat(half,:),axesflag=0,rect=rectc)
g=gca()
gc=g.children(1)
polyl=gc.children
polyl.thickness=5
polyl.line_style=1
 
xset("line style",1)
plot2d([1:nx],scale(nscale)*ones(1,nx),axesflag=0)
g=gca()
gc=g.children(1)
polyl=gc.children
polyl.line_style=1
 
xset("line style",3)
 
xsegs([1 ; nx] .*. ones(1,nscale-2),[scale(2:$-1) ; scale(2:$-1) ])
xsegs([2:nx-1 ; 2:nx-1],[scale(1)*ones(1,nx-2) ;scale($)*ones(1,nx-2)])

    
drawnow()
 
endfunction
