function pltdma_probvar(res,vari)

// PURPOSE: plots the probability that a variable belongs to a
// model and the expected coefficient of this variable
// ------------------------------------------------------------
// INPUT:
// * res = the results typed tlist from a DMA estimation
// * vari = a string, the name of the variable between quotes
// ------------------------------------------------------------
// OUTPUT:
// nothing: all results are plotted on a news graphing window
// ------------------------------------------------------------
// Copyright: Eric Dubois 2012
// http://dubois.ensae.net/grocer.html

probvar=res('vars proba');
namey=res('namey');
variable_namex=res('variable namex');
fixed_namex=res('fixed namex');
nfixed=size(fixed_namex,1)
namex=[fixed_namex ;variable_namex]
vars_proba=res('vars proba');
expected_coeff=res('exp theta');

if vari =='all' then
   ind_vars=1:size(fixed_namex,1)+size(variable_namex,1)
else 
   nvari=size(vari,'*')
   ind_vars=zeros(nvari,1)
   for i=1:nvari
       ind_vars_i=find(vari(i) == namex );
       if isempty(ind_vars_i) then
          error('not a variable in the model: '+vari(i))
       else
          ind_vars(i)=ind_vars_i
       end

   end
end

for i=ind_vars
   grocer_win=max(winsid())+1
   impact_vari=expected_coeff(:,i)
   if res('prests') then
      boun=res('bounds')
      dat=[]
      for j=1:size(boun,1)/2
         [bn1,fq]=date2num_fq(boun(2*(j-1)+1))
         bn2=date2num(boun(2*j))
         dat=[dat ; bn1:bn2]
      end
      impact_vari=tlist(['ts';'freq';'dates';'series'],fq,dat,impact_vari)
   end
   if i <= nfixed then
      pltseries('impact_vari','title=estimated impact of '+namex(i),...
                'noleg','window='+string(grocer_win))
   else
      proba_vari=vars_proba(:,i-nfixed)
      if res('prests') then
         proba_vari=tlist(['ts';'freq';'dates';'series'],fq,dat,proba_vari)
      end
      pltseries('proba_vari','impact_vari','title=estimated probability and impact of '+namex(i),...
                'legend=probabilty of inclusion (lhs);expected coefficient (rhs)','yaxis=[1 2,]',...
                 'window='+string(grocer_win))
   end
end
endfunction
