function [ind_leftpar,ind_rightpar,ind_fuspar]=sci_find_parenth(statk,typepar,preced)
  
// PURPOSE: in a Scilab expressuion, find the indexes of left and
// right parentheses of a statement component and add them to
// the corresponding list reltive to a whole statement
// ------------------------------------------------------------
// INPUT:
// * statk = a gauss statement component
// * typepar = a (2 x 1) matrix, the type of searched 
//   parentheses (['(' ; ')'] or ['[' ; ']'])
// * preced = a scalar, the precedence attributed to the 
//   parentheses
// ------------------------------------------------------------
// OUTPUT:
// * ind_leftpar = the original matrix extended with the 
//   parentheses '(' found in the statement component
// * ind_rightpar = the original matrix extended with the 
//   parentheses ')' found in the statement component
// * ind_fuspar = the fusion of ind_leftpar and ind_rghtpar,
//   with a 4th row cumulating the signed index of the 
//   parentheses (+1 for a left parenthesis, -1 for a right one)
// ------------------------------------------------------------
// Copyright Eric Dubois 2011
// http://dubois.ensae.net/grocer.html


// find indexes of left parentheses
ind_leftpar=strindex(statk,typepar(1))
if ~isempty(ind_leftpar) then
   ind_leftpar=[ind_leftpar ; ...
                  0*ind_leftpar+1 ;...
                  preced*ones(1,size(ind_leftpar,2))]
end
         
// find indexes of right parentheses
ind_rightpar=strindex(statk,typepar(2))
if ~isempty(ind_rightpar) then
   ind_rightpar=[ind_rightpar ; ...
                 0*ind_rightpar+1 ;...
                 preced*ones(1,size(ind_rightpar,2))]
end

ind_fuspar=fusion_par(ind_leftpar,ind_rightpar)   

endfunction
